/*
--------------------------------------------------------------------------------
Example file to show usage of LawnMaker 1.2

This example demonstrates the excessive use of patterns to model a small
grasspatch in almost every aspect.
The result is a round grasspatch wih the blades pointing outward from the center
and inklining more and more to the ground the more to the rim of the patch they
are planted.
--------------------------------------------------------------------------------
*/

//+w640 +h450 +a0.3 +am2 +bm2 +bs8 +wt6

#version 3.8;

#include "lawnmaker.inc"

global_settings {
  assumed_gamma 1.0
  max_trace_level 5
  radiosity {
    pretrace_start 0.08
    pretrace_end   0.04
    count 50, 1000
    nearest_count 10, 5
    error_bound 1
    recursion_limit 2
    low_error_factor .3
    gray_threshold 0.0
    minimum_reuse 0.015
    maximum_reuse 0.1
    brightness 1

    adc_bailout 0.01/2
    normal off
    media off
    always_sample off
    //max_sample 1.0
  }
}

sphere {0, 1e4 pigment {rgb 0.5} finish {emission 1.0 diffuse 0.0}}

plane {y, 0.0 pigment {rgb 0.5}}

camera { 
  location  <0, 5, -7> 
  direction 1.5*z
  right     x*image_width/image_height
  angle     40
  look_at   <0.0, 0.5, 0.0>
}

light_source {
  <-30, 30, -30>            
  color rgb <0.98, 0.98, 0.97>*3 
}

light_source {
  <30, 30, 30>            
  color rgb <1, 1, 1>*0.1 
  shadowless
}

//======================================================================================
// Only the necessary values are changed
#declare LawnStart = <-2, -2>;
#declare LawnStop  = < 2,  2>;
#declare LawnStepX = <0.06, 0.08>;
#declare LawnStepZ = <0.06, 0.08>;

#declare LawnPosStretch = 0.2;
#declare LawnPosition = pigment { cylindrical scale 3 color_map { [0.4, rgb 0] [1, rgb 1] } }

#declare LawnHeight = pigment { cylindrical scale 3 color_map { [0.4, rgb 0] [1, rgb 1] } 
                                turbulence 0.3 }
#declare LawnType   = pigment { cylindrical scale 3 color_map { [0.4, rgb 0] [1, rgb 1] }
                                turbulence 0.21 }
#declare LawnDirection   = pigment { radial color_map { [0, rgb 0] [1, rgb 1] }
                                     turbulence 0.6  }
#declare LawnInclination = pigment { cylindrical color_map { [0, rgb 0] [1, rgb 1] }
                                     turbulence 0.2 scale 3 }


#declare T = 3;
#declare TypeGeometry = array[T] { Blade3,     Blade2,      Blade1     }
#declare TypeWeight   = array[T] { 1,          2,           3          }
#declare TypeSize1    = array[T] { <1,.6,1>,   <1,.5,1>,    <1,.4,1>   }
#declare TypeSize2    = array[T] { <1,1.5,1>,  <1,1.4,1>,   <1,1.2,1>  }
#declare TypeColMap   = array[T] { 1,          1,           1          }
#declare TypeTurn     = array[T] { <0, 360>,   <0, 360>,    <0, 360>   }
#declare TypeIncline  = array[T] { <0, 30>,    <0, 20>,     <0, 10>    }

// invoking LawnMaker and thus actually producing the grass
LawnMaker()
GrassPatch

